==> quasi88-0.5.4.tgz: quasi88-0.5.4/src/quasi88.h <==
#ifndef QUASI88_H_INCLUDED
#define QUASI88_H_INCLUDED


/*----------------------------------------------------------------------*/
/* 								*/
/*----------------------------------------------------------------------*/

typedef	unsigned char	Uchar;
typedef	unsigned short	Ushort;
typedef	unsigned int	Uint;
typedef	unsigned long	Ulong;

typedef unsigned char  byte;
typedef unsigned short word;
typedef signed   char  offset;


typedef unsigned char  bit8;
typedef unsigned short bit16;
typedef unsigned BIT32 bit32;


#define	countof(arr)	(int)(sizeof(arr)/sizeof((arr)[0]))


#ifdef LSB_FIRST			/* ȥ륨ǥ */

typedef union
{
  struct { byte l,h; }	B;
  word			W;
} pair;

#else					/* ӥåǥ */

typedef union
{
  struct { byte h,l; }	B;
  word			W;
} pair;

#endif



#ifndef TRUE
#define	TRUE	(1)
#endif
#ifndef FALSE
#define	FALSE	(0)
#endif



#ifndef	INLINE
#define	INLINE	static
#endif



/*----------------------------------------------------------------------*/
/* ѿ (verbose_*)ؿ						*/
/*----------------------------------------------------------------------*/
extern	int	verbose_level;		/* Ĺ٥			*/
extern	int	verbose_proc;		/* οʹԾɽ		*/
extern	int	verbose_z80;		/* Z80顼ɽ		*/
extern	int	verbose_io;		/* ̤ I/O	*/
extern	int	verbose_pio;		/* PIO Ѥɽ		*/
extern	int	verbose_fdc;		/* FD᡼۾		*/
extern	int	verbose_wait;		/* Ԥΰ۾	*/
extern	int	verbose_suspend;	/* ڥɻΰ۾	*/
extern	int	verbose_snd;		/* ɤΥå		*/


void	main_exit( int val );
void	main_reset( void );



/*----------------------------------------------------------------------*/
/*	ǥХåѤ˲̤ե˥ (®٤㲼ޤ)	*/
/*----------------------------------------------------------------------*/

/*#define PIO_DISP*/		/* PIO طΥ̤ɽ     */
/*#define PIO_FILE*/		/*		   ե˽ */

/*#define FDC_DISP*/		/* FDC طΥ̤ɽ     */
/*#define FDC_FILE*/		/*		   ե˽ */

/*#define MAIN_DISP*/		/* ᥤ Z80 طΥ̤ɽ */
/*#define MAIN_FILE*/		/*		   ե˽    */

/*#define SUB_DISP*/		/*  Z80 طΥ̤ɽ */
/*#define SUB_FILE*/		/*		   ե˽  */


#ifndef	USE_MONITOR
#undef PIO_DISP
#undef PIO_FILE
#undef FDC_DISP
#undef FDC_FILE
#undef MAIN_DISP
#undef MAIN_FILE
#undef SUB_DISP
#undef SUB_FILE
#endif


/* ե˼ϡե򳫤 */
#if defined(PIO_FILE) || defined(FDC_FILE) || defined(MAIN_FILE) || defined(SUB_FILE)
#include <stdio.h>
extern	FILE	*LOG;
#endif


/* ϤΥޥ							*/
/*	ĹδؿƤӽФޥǤ롣			*/
/*	ޥΤΤ̵ˤˤϡ̤ˤ			*/
/*		#define  logxxx   (void)				*/
/*		#define  logxxx   if(1){}else printf			*/
/*	ʤɤȤԤǤϥ˥󥰤ФΤǸԤѤ*/


#if	defined( PIO_DISP ) || defined( PIO_FILE )
void	logpio( const char *format, ... );
#else
#define	logpio	if(1){}else printf
#endif

#if	defined( FDC_DISP ) || defined( FDC_FILE )
void	logfdc( const char *format, ... );
#else
#define	logfdc	if(1){}else printf
#endif

#if	defined( MAIN_DISP ) || defined( MAIN_FILE ) || defined( SUB_DISP ) || defined( SUB_FILE )
void	logz80( const char *format, ... );
#else
#define	logz80	if(1){}else printf
#endif



#endif		/* QUASI88_H_INCLUDED */

==> quasi88-0.6.2.tgz: quasi88-0.6.2/src/quasi88.h <==
#ifndef QUASI88_H_INCLUDED
#define QUASI88_H_INCLUDED


/*----------------------------------------------------------------------*/
/* ƥࡦĶ¸						*/
/*----------------------------------------------------------------------*/
#include "config.h"


/*----------------------------------------------------------------------*/
/* ե륷ƥ¸						*/
/*----------------------------------------------------------------------*/
#include "filename.h"


/* QUASI88 ݻǽʥѥߤΥե̾Хȿ (NULޤ) */
#define	QUASI88_MAX_FILENAME	(1024)


/*----------------------------------------------------------------------*/
/* С							*/
/*----------------------------------------------------------------------*/
#include "version.h"



/*----------------------------------------------------------------------*/
/* 								*/
/*----------------------------------------------------------------------*/

typedef	unsigned char	Uchar;
typedef	unsigned short	Ushort;
typedef	unsigned int	Uint;
typedef	unsigned long	Ulong;

typedef unsigned char  byte;
typedef unsigned short word;
typedef signed   char  offset;


typedef unsigned char  bit8;
typedef unsigned short bit16;
typedef unsigned int   bit32;


#define	COUNTOF(arr)	(int)(sizeof(arr)/sizeof((arr)[0]))
#define	OFFSETOF(s, m)	((size_t)(&((s *)0)->m))
#define	MAX(a,b)	(((a)>(b))?(a):(b))
#define	MIN(a,b)	(((a)<(b))?(a):(b))
#define	ABS(x)		( ((x) >= 0)? (x) : -(x) )
#define	SGN( x )	( ((x)>0) ? 1 : ( ((x)<0) ? -1 : 0 ) ) 


#ifdef LSB_FIRST			/* ȥ륨ǥ */

typedef union
{
  struct { byte l,h; }	B;
  word			W;
} pair;

#else					/* ӥåǥ */

typedef union
{
  struct { byte h,l; }	B;
  word			W;
} pair;

#endif



#ifndef TRUE
#define	TRUE	(1)
#endif
#ifndef FALSE
#define	FALSE	(0)
#endif



#ifndef	INLINE
#define	INLINE	static
#endif



/*----------------------------------------------------------------------*/
/* ѿ (verbose_*)ؿ						*/
/*----------------------------------------------------------------------*/
extern	int	verbose_level;		/* Ĺ٥			*/
extern	int	verbose_proc;		/* οʹԾɽ		*/
extern	int	verbose_z80;		/* Z80顼ɽ		*/
extern	int	verbose_io;		/* ̤ I/O	*/
extern	int	verbose_pio;		/* PIO Ѥɽ		*/
extern	int	verbose_fdc;		/* FD᡼۾		*/
extern	int	verbose_wait;		/* Ԥΰ۾	*/
extern	int	verbose_suspend;	/* ڥɻΰ۾	*/
extern	int	verbose_snd;		/* ɤΥå		*/


#define	INIT_POWERON	(0)
#define	INIT_RESET	(1)
#define	INIT_STATELOAD	(2)

int	quasi88( void );
void	quasi88_atexit( void (*function)(void) );
void	quasi88_exit( void );
void	quasi88_reset( void );
int	quasi88_stateload( void );



char	*alloc_diskname( const char *filename );
char	*alloc_romname( const char *filename );
char	*alloc_global_cfgname( void );
char	*alloc_local_cfgname( const char *imagename );
char	*alloc_state_filename( int init );
char	*alloc_snapshot_filename( int init );



/*----------------------------------------------------------------------*/
/* ¾	(Τϡ quasi88.c  ˤƤ)			*/
/*----------------------------------------------------------------------*/
void	sjis2euc( char *euc_p, const char *sjis_p );
void	euc2sjis( char *sjis_p, const char *euc_p );
int	euclen( const char *euc_p );
int	my_strcmp( const char *s, const char *d );
void	my_strncpy( char *s, const char *ct, unsigned long n );
void	my_strncat( char *s, const char *ct, unsigned long n );



/*----------------------------------------------------------------------*/
/*	ǥХåѤ˲̤ե˥ (®٤㲼ޤ)	*/
/*----------------------------------------------------------------------*/

/*#define PIO_DISP*/		/* PIO طΥ̤ɽ     */
/*#define PIO_FILE*/		/*		   ե˽ */

/*#define FDC_DISP*/		/* FDC طΥ̤ɽ     */
/*#define FDC_FILE*/		/*		   ե˽ */

/*#define MAIN_DISP*/		/* ᥤ Z80 طΥ̤ɽ */
/*#define MAIN_FILE*/		/*		   ե˽    */

/*#define SUB_DISP*/		/*  Z80 طΥ̤ɽ */
/*#define SUB_FILE*/		/*		   ե˽  */


#ifndef	USE_MONITOR
#undef PIO_DISP
#undef PIO_FILE
#undef FDC_DISP
#undef FDC_FILE
#undef MAIN_DISP
#undef MAIN_FILE
#undef SUB_DISP
#undef SUB_FILE
#endif


/* ե˼ϡե򳫤 */
#if defined(PIO_FILE) || defined(FDC_FILE) || defined(MAIN_FILE) || defined(SUB_FILE)
#include <stdio.h>
extern	FILE	*LOG;
#endif


/* ϤΥޥ							*/
/*	ĹδؿƤӽФޥǤ롣			*/
/*	ޥΤΤ̵ˤˤϡ̤ˤ			*/
/*		#define  logxxx   (void)				*/
/*		#define  logxxx   if(1){}else printf			*/
/*	ʤɤȤԤǤϥ˥󥰤ФΤǸԤѤ*/


#if	defined( PIO_DISP ) || defined( PIO_FILE )
void	logpio( const char *format, ... );
#else
#define	logpio	if(1){}else printf
#endif

#if	defined( FDC_DISP ) || defined( FDC_FILE )
void	logfdc( const char *format, ... );
#else
#define	logfdc	if(1){}else printf
#endif

#if	defined( MAIN_DISP ) || defined( MAIN_FILE ) || defined( SUB_DISP ) || defined( SUB_FILE )
void	logz80( const char *format, ... );
#else
#define	logz80	if(1){}else printf
#endif



#endif		/* QUASI88_H_INCLUDED */
